package com.ruoyi.abuwx.service.exam;

import com.ruoyi.abuwx.domain.exam.ExmQuestion;

import java.util.List;

/**
 * 试题Service接口
 * 
 * @author ruoyi
 * @date 2024-05-17
 */
public interface IExmQuestionService 
{
    /**
     * 查询试题
     * 
     * @param id 试题主键
     * @return 试题
     */
    public ExmQuestion selectExmQuestionById(Long id);

    /**
     * 查询试题列表
     * 
     * @param exmQuestion 试题
     * @return 试题集合
     */
    public List<ExmQuestion> selectExmQuestionList(ExmQuestion exmQuestion);

    /**
     * 新增试题
     * 
     * @param exmQuestion 试题
     * @return 结果
     */
    public int insertExmQuestion(ExmQuestion exmQuestion);

    /**
     * 修改试题
     * 
     * @param exmQuestion 试题
     * @return 结果
     */
    public int updateExmQuestion(ExmQuestion exmQuestion);

    /**
     * 批量删除试题
     * 
     * @param ids 需要删除的试题主键集合
     * @return 结果
     */
    public int deleteExmQuestionByIds(Long[] ids);

    /**
     * 删除试题信息
     * 
     * @param id 试题主键
     * @return 结果
     */
    public int deleteExmQuestionById(Long id);
}
